import { ChangeDetectionStrategy, Component, inject, OnInit, signal } from '@angular/core';
import { RouterModule } from '@angular/router';
import { UserService } from '../../../service/user.service';
import { CurrencyPipe } from '@angular/common';
import { AuthService } from '../../../service/auth.service';

@Component({
  selector: 'app-navbar',
  templateUrl: './navbar.component.html',
  standalone: true,
  imports: [RouterModule, CurrencyPipe],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class NavbarComponent implements OnInit {
  isMenuOpen = false;
  private authService: AuthService = inject(AuthService);
  isLoggedIn = this.authService.isLoggedIn();

  private userService = inject(UserService);
  private user = this.userService.getCurrentUser();

  public balance = signal(0);

  ngOnInit() {
    this.user.subscribe((user) => {
      this.balance.set(user?.balance ?? 0);
    });
  }

  login() {
    try {
      this.authService.login();
    } catch (error) {
      console.error('Login failed:', error);
    }
  }

  logout() {
    this.authService.logout();
  }

  toggleMenu() {
    this.isMenuOpen = !this.isMenuOpen;
  }
}
